BioContextAligner
=================

.. currentmodule:: bioregistry.align

.. autoclass:: BioContextAligner
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~BioContextAligner.curation_header
      ~BioContextAligner.key

   .. rubric:: Methods Summary

   .. autosummary::

      ~BioContextAligner.get_curation_row
      ~BioContextAligner.get_skip
      ~BioContextAligner.getter
      ~BioContextAligner.prepare_external

   .. rubric:: Attributes Documentation

   .. autoattribute:: curation_header
   .. autoattribute:: key

   .. rubric:: Methods Documentation

   .. automethod:: get_curation_row
   .. automethod:: get_skip
   .. automethod:: getter
   .. automethod:: prepare_external
